#[non_exhaustive]pub enum DiffSizeStrictness {
None,
Apply,
Generate,
}Expand description
A degree of strictness to apply when checking the size of a diff versus the size of the associated consensus.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
Do not perform any checks.
Apply
Check whether the diff is reasonable to apply to the input.
Generate
Check whether the diff is reasonable to serve as a diff against the input.
This is an even stricter version of DiffSizeStrictness::Apply.
Implementations