Enum tor_consdiff::Error [−][src]
An error type from the tor-consdiff crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadDiff(&'static str)We got a consensus diff that we couldn’t parse, or which we found to be somehow invalid.
Tuple Fields of BadDiff
0: &'static strCantApply(&'static str)We got a consensus diff that looked valid, but we couldn’t apply it to the given input.
Tuple Fields of CantApply
0: &'static strTrait Implementations
Performs the conversion.
Performs the conversion.