GenEdDiffError

Enum GenEdDiffError 

pub(crate) enum GenEdDiffError {
    MissingUnixLineEnding {
        lno: usize,
    },
    ContainsDotLine {
        lno: usize,
    },
    Write(Error),
}
An error type for consensus diff generation.

Variants



MissingUnixLineEnding

Line does not end with a Unix line ending.

Fields

lno: usize

The line number of the missing newline.



ContainsDotLine

Diff results in the insertion of a line with a single dot, which is not possible according to the specification.

Fields

lno: usize

The line number of the missing newline.



Write(Error)

Formatting error, mostly convenience to allow for ? in write calls.