pub struct DiffResult<'a> {
pub(crate) d_post: [u8; 32],
pub(crate) lines: Vec<&'a str>,
}Expand description
The result of applying one or more diff commands to an input string.
It refers to lines from the diff and the input by reference, to avoid copying.
Fields
d_post: [u8; 32]An expected digest of the output, after it has been assembled.
lines: Vec<&'a str>The lines in the output.
Implementations
Sourceimpl<'a> DiffResult<'a>
impl<'a> DiffResult<'a>
Sourcepub(crate) fn from_str(s: &'a str, d_post: [u8; 32]) -> Self
pub(crate) fn from_str(s: &'a str, d_post: [u8; 32]) -> Self
Construct a new DiffResult containing the provided string split into lines, and an expected post-transformation digest.
Sourcepub(crate) fn new(d_post: [u8; 32]) -> Self
pub(crate) fn new(d_post: [u8; 32]) -> Self
Return a new empty DiffResult with an expected post-transformation digests
Sourcepub(crate) fn push_reversed(&mut self, lines: &[&'a str])
pub(crate) fn push_reversed(&mut self, lines: &[&'a str])
Put every member of lines at the end of this DiffResult, in
reverse order.
Sourcepub(crate) fn remove_lines(
&mut self,
first: usize,
last: usize,
) -> Result<(), Error>
pub(crate) fn remove_lines( &mut self, first: usize, last: usize, ) -> Result<(), Error>
Remove the 1-indexed lines from first through last inclusive.
This has to move elements around within the vector, and so it is potentially O(n) in its length.
Sourcepub(crate) fn insert_at(
&mut self,
pos: usize,
lines: &[&'a str],
) -> Result<(), Error>
pub(crate) fn insert_at( &mut self, pos: usize, lines: &[&'a str], ) -> Result<(), Error>
Insert the provided lines so that they appear at 1-indexed
position pos.
This has to move elements around within the vector, and so it is potentially O(n) in its length.
Sourcepub fn check_digest(&self) -> Result<(), Error>
pub fn check_digest(&self) -> Result<(), Error>
See whether the output of this diff matches the target digest.
If not, return an error.