pub(crate) enum GenEdDiffError {
MissingUnixLineEnding {
lno: usize,
},
ContainsDotLine {
lno: usize,
},
Write(Error),
}Expand description
An error type for consensus diff generation.
Variants
MissingUnixLineEnding
Line does not end with a Unix line ending.
ContainsDotLine
Diff results in the insertion of a line with a single dot, which is not possible according to the specification.
Write(Error)
Formatting error, mostly convenience to allow for ? in write calls.