pub struct DiffResult<'a> { /* private fields */ }Expand description
The result of applying one or more diff commands to an input string.
It refers to lines from the diff and the input by reference, to avoid copying.
Implementations
Sourceimpl<'a> DiffResult<'a>
impl<'a> DiffResult<'a>
Sourcepub fn check_digest(&self) -> Result<(), Error>
pub fn check_digest(&self) -> Result<(), Error>
See whether the output of this diff matches the target digest.
If not, return an error.